@@ -56,7 +56,7 @@ KateFileTree::KateFileTree(QWidget *parent): QTreeView(parent)
     setIndentation(12);
     setAllColumnsShowFocus(true);
 
-    connect(this, SIGNAL(activated(QModelIndex)), this, SLOT(mouseClicked(QModelIndex)));
+    connect(this, SIGNAL(clicked(QModelIndex)), this, SLOT(mouseClicked(QModelIndex)));
 
     m_filelistReloadDocument = new QAction(QIcon::fromTheme(QLatin1String("view-refresh")), i18nc("@action:inmenu", "Reloa&d"), this);
     connect(m_filelistReloadDocument, SIGNAL(triggered(bool)), SLOT(slotDocumentReload()));
@@ -127,7 +127,7 @@ KateFileTree::~KateFileTree()
 
 void KateFileTree::setModel(QAbstractItemModel *model)
 {
-    Q_ASSERT(qobject_cast<KateFileTreeProxyModel *>(model)); // we dont' realy work with anything else
+    Q_ASSERT(qobject_cast<KateFileTreeProxyModel *>(model)); // we don't really work with anything else
     QTreeView::setModel(model);
 }
 
@@ -308,14 +308,14 @@ void KateFileTree::slotOpenWithMenuAction(QAction *a)
         // display "open with" dialog
         KOpenWithDialog dlg(list);
         if (dlg.exec()) {
-            KRun::run(*dlg.service(), list, this);
+            KRun::runService(*dlg.service(), list, this);
         }
         return;
     }
 
     KService::Ptr app = KService::serviceByDesktopPath(openWith);
     if (app) {
-        KRun::run(*app, list, this);
+        KRun::runService(*app, list, this);
     } else {
         KMessageBox::error(this, i18n("Application '%1' not found.", openWith), i18n("Application not found"));
     }
